@@ -33,6 +33,7 @@ res = lgcp(data=myPoints, grid=20, covariates=mycov,
 plot(res$raster[["predict.exp"]])
 plot(myPoints,add=TRUE,col="#0000FF30",cex=0.5)
 
+if(interactive()  | Sys.info()['user'] =='patrick') {
 	# dodgy formula
 
 res = lgcp(data=myPoints, grid=20, covariates=mycov,
@@ -58,4 +59,5 @@ res = lgcp(data=myPoints, grid=20, covariates=mycov,
 plot(res$raster[["predict.exp"]])
 plot(myPoints,add=TRUE,col="#0000FF30",cex=0.5)
 
-}	
\ No newline at end of file
+}	
+}
\ No newline at end of file
